@@ -26,7 +26,6 @@ setMethod("show", "hypothesesTree", function(object)
           unadj.p.values <- slot(object, "unadj.p.values")
           adj.p.values <- slot(object, "adj.p.values")
           rejected.hypotheses <- slot(object, "rejected.hypotheses")
-          require(igraph)
           nHypotheses <- length(hypothesesNames)
           igraph.tree <- graph.adjacency(tree)
           nEdges <- length(E(igraph.tree))
@@ -49,8 +48,8 @@ setMethod("plot", "hypothesesTree", function(x,..., p.values.type = "unadjusted"
           p.values.type <- tolower(p.values.type)
           p.values.type <- match.arg(p.values.type, c("unadjusted", "adjusted"))
           if(p.values.type == "unadjusted"){
-              plotUnadjustedHypothesesTree(x, alpha)
+            plotUnadjustedHypothesesTree(x, alpha)
           } else if(p.values.type == "adjusted"){
-              plotAdjustedHypothesesTree(x)
+            plotAdjustedHypothesesTree(x)
           }
-      })
+        })
